@@ -1,9 +1,9 @@
 use hyper::{Body, Client, Request};
-use hyper_trust_dns::new_trust_dns_http_connector;
+use hyper_trust_dns::TrustDnsResolver;
 
 #[tokio::test]
 async fn test_lookup_works() {
-    let connector = new_trust_dns_http_connector();
+    let connector = TrustDnsResolver::default().into_http_connector();
     let client = Client::builder().build(connector);
 
     let request = Request::builder()
